<?php 
// Don't load directly
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}
/**
 * Manger for Product Template post type for single product design with constructor
 *
 * @package WooCommercePageBuilder
 * @since 4.0
 */

if ( ! class_exists( 'dtwpb_posttype_product_tpl' ) ) {
	
	require_once vc_path_dir( 'EDITORS_DIR', 'class-vc-backend-editor.php' );
	
	class dtwpb_posttype_product_tpl extends Vc_Backend_Editor{
		protected static $post_type = 'dtwpb_product_tpl';
		protected $templates_editor = false;
		
		/**
		 * This method is called to add hooks.
		 *
		 * @since  4.8
		 * @access public
		 */
		public function addHooksSettings(){
			parent::addHooksSettings();
		}
		
		public function render( $post_type ) {
			if ( $this->isValidPostType( $post_type ) ) {
				$this->registerBackendJavascript();
				$this->registerBackendCss();
				// B.C:
				visual_composer()->registerAdminCss();
				visual_composer()->registerAdminJavascript();
				// Disbale Frontend
				vc_disable_frontend();
				
			}
		}
		
		public function dtwpb_woocommerce_disable_gutenberg( $can_edit, $post_type ){
			if ($post_type === 'dtwpb_product_tpl' ) return false;
		
			return $can_edit;
		}
		
		public function editorEnabled() {
			return true;
		}
		
		/**
		 * Rewrites validation for correct post_type of th post.
		 *
		 * @param string $type
		 *
		 * @return bool
		 */
		public function isValidPostType( $type = '' ) {
			$type = ! empty( $type ) ? $type : get_post_type();
			return $this->editorEnabled() && $this->postType() === $type;
		}

		public static function createPostType() {
			
			if ( post_type_exists( self::$post_type && !class_exists('WooCommerce') ) )
				return;
			
			register_post_type( self::$post_type, array( 
						'labels' => self::getPostTypesLabels(),
						'public' => true,
						'has_archive' => false,
						'show_in_nav_menus' => false,
						'exclude_from_search' => true,
						'publicly_queryable' => false,
						'show_ui' => true,
						'show_in_menu' => false,
						'query_var' => true,
						'capability_type' => 'post',
						'hierarchical' => false,
						'menu_position' => null,
						'supports' => array( 'title','editor','revisions' )
			 ) );
			
		}
		
		/**
		 * @return array
		 */
		public static function getPostTypesLabels(){
			return array(
				'add_new_item' => esc_html__( 'Add New Product Template', 'dt_woocommerce_page_builder' ),
				'name' => esc_html__( 'Product Templates', 'dt_woocommerce_page_builder' ),
				'singular_name' => esc_html__( 'Product Template', 'dt_woocommerce_page_builder' ),
				'edit_item' => esc_html__( 'Edit Product Template', 'dt_woocommerce_page_builder' ),
				'view_item' => esc_html__( 'View Product Template', 'dt_woocommerce_page_builder' ),
				'search_items' => esc_html__( 'Search Product Templates', 'dt_woocommerce_page_builder' ),
				'not_found' => esc_html__( 'No Product Templates found', 'dt_woocommerce_page_builder' ),
				'not_found_in_trash' => esc_html__( 'No Product Templates found in trash', 'dt_woocommerce_page_builder' ),
			);
		}
		
		public static function postType(){
			return self::$post_type;
		}
				
		public static function remove_row_actions($actions){
			if( get_post_type() === 'dtwpb_product_tpl' )
				unset( $actions['edit_vc'] );
			return $actions;
		}
	}
}